Spin Box Example
===============================================================================

:download:`spin_box.enaml <../../../examples/components/spin_box.enaml>`

.. literalinclude:: ../../../examples/components/spin_box.enaml
    :language: python

::

 $ enaml-run spin_box.enaml
 new value 12
 new value 1
 new value 2

.. image:: images/spin_box.png
